# Copyright (c) Project Jupyter.
# Distributed under the terms of the Modified BSD License.

version_info = (0, 22, 1)
flag = ""

__version__ = ".".join(map(str, version_info)) + flag
